#
# spec file for package ghc-time-compat
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name time-compat
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        1.9.8
Release:        1.3
Summary:        Compatibility package for time
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-orphans-devel
BuildRequires:  ghc-base-orphans-prof
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-deepseq-prof
BuildRequires:  ghc-hashable-devel
BuildRequires:  ghc-hashable-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-template-haskell-devel
BuildRequires:  ghc-template-haskell-prof
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-time-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-HUnit-prof
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-QuickCheck-prof
BuildRequires:  ghc-random-devel
BuildRequires:  ghc-random-prof
BuildRequires:  ghc-tagged-devel
BuildRequires:  ghc-tagged-prof
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-hunit-devel
BuildRequires:  ghc-tasty-hunit-prof
BuildRequires:  ghc-tasty-prof
BuildRequires:  ghc-tasty-quickcheck-devel
BuildRequires:  ghc-tasty-quickcheck-prof
%endif

%description
This packages tries to compat as much of 'time' features as possible.

/TODO:/

* Difference type 'ParseTime' and 'FormatTime' instances are missing.

* Formatting varies depending on underlying 'time' version

* 'dayFractionToTimeOfDay' on extreme values.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Thu Dec 26 2024 Peter Simons <psimons@suse.com>
- Update time-compat to version 1.9.8.
  Upstream has not updated the file "CHANGELOG.md" since the last
  release.
* Thu Jul  4 2024 Peter Simons <psimons@suse.com>
- Update time-compat to version 1.9.7 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon May 13 2024 Peter Simons <psimons@suse.com>
- Update time-compat to version 1.9.7.
  [#] 1.9.7
  - Drop support for GHCs prior 8.6.5
* Wed Oct  4 2023 Peter Simons <psimons@suse.com>
- Update time-compat to version 1.9.6.1 revision 6.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Sun Mar 12 2023 Peter Simons <psimons@suse.com>
- Update time-compat to version 1.9.6.1 revision 5.
  Upstream has revised the Cabal build instructions on Hackage.
* Wed Aug 10 2022 Peter Simons <psimons@suse.com>
- Update time-compat to version 1.9.6.1 revision 4.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Nov 16 2021 psimons@suse.com
- Update time-compat to version 1.9.6.1 revision 3.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Nov  1 2021 psimons@suse.com
- Update time-compat to version 1.9.6.1 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Sep  2 2021 psimons@suse.com
- Update time-compat to version 1.9.6.1.
  [#] 1.9.6.1
  - Support `time-1.12`.
* Thu May 20 2021 psimons@suse.com
- Update time-compat to version 1.9.6.
  [#] 1.9.6
  - Move `Hashable` instance here from `hashable-time` package.
    Note: `ZonedTime` instance is dropped, as `ZonedTime` doesn't have `Eq`
    instance.
  - Drop GHC-7.0 and GHC-7.2 support.
* Mon Feb 15 2021 psimons@suse.com
- Update time-compat to version 1.9.5 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Sun Dec  6 2020 psimons@suse.com
- Update time-compat to version 1.9.5.
  [#] 1.9.5
  - Support `time-1.11.1`
  - Add `NFData CalandarDiffDays` instance
* Mon Nov  2 2020 psimons@suse.com
- Update time-compat to version 1.9.4.
  [#] 1.9.4
  - Support `time-1.11`
  - `Data.Time.Calendar.Month`
  - `Data.Time.Calendar.Quarter`
  - Pattern synonyms
  - `parseTimeMultipleM` is not backported
  - `Month` is missing `ParseTime` instance
  - Compat extras:
  - Add `Ix`, `Enum`, `NFData` instances to `Month`, `Quarter`, `QuarterOfYear`,
    `CalendarDiffTime` and `DayOfWeek`.
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Wed May  6 2020 psimons@suse.com
- Update time-compat to version 1.9.3.
  Upstream added a new change log file in this release. With no
  previous version to compare against, the automatic updater cannot
  reliable determine the relevante entries for this release.
* Wed Jan  1 2020 psimons@suse.com
- Drop obsolete code to create a Setup.hs file. The RPM macros do
  this automatically now.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Tue Jun 11 2019 psimons@suse.com
- Add time-compat at version 1.9.2.2.
